@@ -431,18 +431,17 @@ def main():
 	if values.cluster:
 		myfamily = values.cluster
 
-	sys.stderr.write("### Start mspminer_protein_family_taxonomy.py -a " + values.annotation + " ####\n")
-	
+	config.logger.info ("### Start mspminer_protein_family_taxonomy step ####")
 
 	### collect cluster info ###
-	sys.stderr.write("Get info ......starting\n")
+	config.logger.info ("Get info ......starting")
 	pep_cluster = collect_pep_cluster_info (myfamily)
 	taxa_map = collect_taxonomy_info (config.taxonomy_database)
 	genes, taxa, ann_title = extract_taxon_info (values.annotation)
 	taxonomy_annotation (genes, taxa, ann_title, config.tshld_lca, taxa_map, values.source, pep_cluster, values.output)
-	sys.stderr.write("Get info ......done\n")
+	config.logger.info ("Get info ......done")
 
-	sys.stderr.write("### Finish mspminer_protein_family_taxonomy.py ####\n\n\n")
+	config.logger.info ("### Finish mspminer_protein_family_taxonomy step ####")
 
 # end: main
 
